@@ -49,7 +49,7 @@ effort<-function(est.type=c("hypothetical", "pilot"), e=NULL, ICC=NULL, x=NULL,
       if(!is.factor(tdata[,2])){
         tdata[,2]<-as.factor(tdata[,2])
         }  
-      tmpbb<-anova.lm(aov(tdata[,1]~tdata[,2], data=tdata))
+      tmpbb<-anova(aov(tdata[,1]~tdata[,2], data=tdata))
       num.df<-tmpbb[1][1,1]
       denom.df<-tmpbb[1][2,1];
       MSa<-tmpbb[3][1,1]
